==> nocc-1.8.3.tbz: www/nocc/lang/id.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: id.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Indonesian (Bahasa Indonesia)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bennylin
 * @author Farras
 * @author Irwangatot
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Bagian login kosong';
$err_passwd_empty = 'Bagian password kosong';
$alt_delete = 'Hapus pesan terpilih';
$alt_delete_one = 'Hapus pesan';
$alt_new_msg = 'Pesan baru';
$alt_reply = 'Balasan ke penulis';
$alt_reply_all = 'Balas semua';
$alt_forward = 'Teruskan';
$alt_next = 'Selanjutnya';
$alt_prev = 'Sebelumnya';
$title_next_page = 'Halaman selanjutnya';
$title_prev_page = 'Halaman sebelumnya';
$title_next_msg = 'Pesan berikutnya';
$title_prev_msg = 'Pesan sebelumnya';
$html_theme_label = 'Tema:';
$html_welcome = 'Selamat datang di %1$s';
$html_login = 'Masuk log';
$html_user_label = 'Pengguna:';
$html_passwd_label = 'Sandi:';
$html_submit = 'Kirim';
$html_help = 'Bantuan';
$html_server_label = 'Server:';
$html_wrong = 'Pengguna atau kata sandi salah';
$html_retry = 'Coba lagi';
$html_remember = 'Ingat pengaturan';
$html_lang_label = 'Bahasa:';
$html_msgperpage_label = 'Pesan perhalaman:';
$html_preferences = 'Preferensi';
$html_full_name_label = 'Nama lengkap:';
$html_email_address_label = 'Alamat surat-e:';
$html_ccself = 'Tembusan sendiri';
$html_hide_addresses = 'Sembunyikan alamat';
$html_outlook_quoting = 'Gaya kutipan-Qutlook';
$html_reply_to = 'Balas ke';
$html_use_signature = 'Gunakan tandatangan';
$html_signature = 'Tanda tangan';
$html_signature_label = 'Tanda tangan:';
$html_reply_leadin_label = 'Balasan diawali:';
$html_prefs_updated = 'Preferensi diperbarui';
$html_manage_folders_link = 'Kelola Folder IMAP';
$html_manage_filters_link = 'Kelola Penyaring Surel';
$html_use_graphical_smilies = 'Gunakan smiley grafis';
$html_sent_folder_label = 'Salin surel terkirim ke folder khusus:';
$html_trash_folder_label = 'Pindahkan surel terhapus ke folder khusus:';
$html_colored_quotes = 'Kutipan berwarna';
$html_display_struct = 'Tampilan teks tersetruktur';
$html_send_html_mail = 'Kirim surel dalam format HTML';
$html_folders = 'Folder';
$html_folders_create_failed = 'Folder tak dapat dibuat!';
$html_folders_sub_failed = 'Tidak bisa berlangganan ke folder!';
$html_folders_unsub_failed = 'Tidak bisa berhenti berlangganan dari folder!';
$html_folders_rename_failed = 'Folder tidak bisa diubah nama!';
$html_folders_updated = 'Folder telah diperbarui';
$html_folder_subscribe = 'Berlangganan ke';
$html_folder_rename = 'Ubah nama';
$html_folder_create = 'Buat foler baru bernama';
$html_folder_remove = 'Berhenti berlangganan dari';
$html_folder_delete = 'Hapus';
$html_folder_to = 'Kepada';
$html_filter_remove = 'Hapus';
$html_filter_body = 'Badan pesan';
$html_filter_subject = 'Subyek pesan';
$html_filter_to = 'Kotak Kepada';
$html_filter_cc = 'Kotak Cc';
$html_filter_from = 'Kotak Dari';
$html_filter_change_tip = 'Untuk mengubah penyaring, tulis/timpa saja kembali.';
$html_reapply_filters = 'Nyalakan kembali semua penyaring';
$html_filter_contains = 'berisi';
$html_filter_name = 'Nama Penyaring';
$html_filter_action = 'Langkah Penyaring';
$html_filter_moveto = 'Pindah ke';
$html_select_one = '--Pilih salahsatu--';
$html_and = 'Dan';
$html_new_msg_in = 'Pesan baru pada';
$html_or = 'atau';
$html_move = 'Pindahkan';
$html_copy = 'Salin';
$html_messages_to = 'Pesan pilihan ke';
$html_gotopage = 'Ke Halaman';
$html_gotofolder = 'Pergi ke Folder';
$html_other_folders = 'Daftar Folder';
$html_page = 'Halaman';
$html_of = 'dari';
$html_view_header = 'Tampilkan kepala';
$html_remove_header = 'Sembunyikan kepala';
$html_inbox = 'Kotak Masuk';
$html_new_msg = 'Tulis';
$html_reply = 'Balas';
$html_reply_short = 'Bl:';
$html_reply_all = 'Balas semua';
$html_forward = 'Teruskan';
$html_forward_short = 'Lnj:';
$html_forward_info = 'Pesan yang diteruskan akan dikirim sebagai lampiran dari pesan ini.';
$html_delete = 'Hapus';
$html_new = 'Baru';
$html_mark = 'Hapus';
$html_att_label = 'Lampiran:';
$html_atts_label = 'Lampiran:';
$html_unknown = '[tidak diketahui]';
$html_attach = 'Terlampir';
$html_attach_forget = 'Anda harus melampirkan berkas sebelum mengirim pesan!';
$html_attach_delete = 'Buang Pilihan';
$html_attach_none = 'Anda harus memilih sebuah berkas untuk dilampirkan!';
$html_sort_by = 'Urut berdasarkan';
$html_sort = 'Urutkan';
$html_from = 'Dari';
$html_from_label = 'Dari:';
$html_subject = 'Perihal';
$html_subject_label = 'Perihal:';
$html_date = 'Tanggal';
$html_date_label = 'Tanggal:';
$html_sent_label = 'Kirim:';
$html_wrote = 'tulis';
$html_size = 'Ukuran';
$html_totalsize = 'Jumlah Ukuran';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nama berkas';
$html_to = 'Kepada';
$html_to_label = 'Kepada:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Tidak ada judul';
$html_send = 'Kirim';
$html_cancel = 'Batalkan';
$html_no_mail = 'Tidak ada pesan.';
$html_logout = 'Keluar log';
$html_msg = 'Pesan';
$html_msgs = 'Pesan';
$html_configuration = 'Server ini belum didirikan!';
$html_priority = 'Prioritas';
$html_priority_label = 'Prioritas:';
$html_lowest = 'Terendah';
$html_low = 'Rendah';
$html_normal = 'Normal';
$html_high = 'Tinggi';
$html_highest = 'Tertinggi';
$html_flagged = 'Ditandai';
$html_receipt = 'Minta tanda kembalian';
$html_select = 'Pilih';
$html_select_all = 'Kembalikan Pilihan';
$html_select_contacts = 'Pilih kontak';
$html_loading_image = 'Memuat gambar';
$html_send_confirmed = 'Surel Anda diterima untuk dikirim';
$html_no_sendaction = 'Tidak ada langkah yang dilakukan. Coba nyalakan JavaScript.';
$html_error_occurred = 'Kesalahan terjadi';
$html_prefs_file_error = 'Tidak bisa membuka berkas preferensi untuk menulis.';
$html_wrap = 'Jumlah karakter untuk membungkus pesan:';
$html_wrap_none = 'Tanpa bungkus';
$html_usenet_separator = 'Pemisah Usenet ("-- \n") sebelum tanda tangan';
$html_mark_as = 'Tandai sebagai';
$html_read = 'sudah dibaca';
$html_unread = 'belum dibaca';
$html_encoding_label = 'Pengkodean karakter:';
$html_add = 'Tambahkan';
$html_contacts = '%1$s kontak';
$html_modify = 'Ubah';
$html_back = 'Kembali';
$html_contact_add = 'Tambah kontak baru';
$html_contact_mod = 'Ubah kontak';
$html_contact_first = 'Nama awal';
$html_contact_last = 'Nama akhir';
$html_contact_nick = 'Panggilan';
$html_contact_mail = 'Surel';
$html_contact_list = 'Daftar kontak %1$s';
$html_contact_del = 'dari daftar kontak';
$html_contact_count = '%1$d kontak';
$html_contact_err1 = 'Jumlah maksimum kontak adalah "%$d"';
$html_contact_err2 = 'Anda tak dapat menambahkan kontak baru';
$html_contact_err3 = 'Anda tak punya hak masuk ke daftar kontak';
$html_contact_none = 'Tak ada kontak yang ditemukan.';
$html_del_msg = 'Hapus pesan terpilih?';
$html_down_mail = 'Unduh';
$original_msg = '-- Pesan Asli --';
$to_empty = 'Kotak \'Kepada\' jangan dikosongkan!';
$html_images_warning = 'Demi keamanan Anda, gambar tertentu tidak ditampilkan.';
$html_images_display = 'Tampilkan gambar';
$html_smtp_error_no_conn = 'Tidak bisa membuka koneksi SMTP';
$html_smtp_error_unexpected = 'Respon SMTP tak terduga:';
$lang_could_not_connect = 'Tak dapat menghubungi server';
$lang_invalid_msg_num = 'Nomor pesan buruk';
$html_file_upload_attack = 'Kemungkinan serangan unggah berkas';
$html_invalid_email_address = 'Alamat surel salah';
$html_invalid_msg_per_page = 'Jumlah pesan per halaman salah';
$html_invalid_wrap_msg = 'Lebar bungkus pesan salah';
$html_seperate_msg_win = 'Pesan di jendela lain';
$html_err_file_contacts = 'Tidak bisa membuka berkas kontak untuk menulis.';
$html_session_file_error = 'Tidak bisa membuka berkas sesi untuk menulis.';
$html_login_not_allowed = 'Masuk log belum diperbolehkan karena masalah koneksi.';
$lang_err_send_delay = 'Anda harus menunggu antara dua surel (%1$d detik)';
$html_search = 'Cari';

==> nocc-1.9.3.tbz: www/nocc/lang/id.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: id.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Indonesian (Bahasa Indonesia)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bennylin
 * @author Dadanhrn
 * @author Farras
 * @author Irwangatot
 * @author IvanLanin
 * @author Mihxil
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Bagian login kosong';
$err_passwd_empty = 'Bagian password kosong';
$alt_delete = 'Hapus pesan terpilih';
$alt_delete_one = 'Hapus pesan';
$alt_new_msg = 'Pesan baru';
$alt_reply = 'Balasan ke penulis';
$alt_reply_all = 'Balas semua';
$alt_forward = 'Teruskan';
$alt_next = 'Selanjutnya';
$alt_prev = 'Sebelumnya';
$title_next_page = 'Halaman selanjutnya';
$title_prev_page = 'Halaman sebelumnya';
$title_next_msg = 'Pesan berikutnya';
$title_prev_msg = 'Pesan sebelumnya';
$html_theme_label = 'Tema:';
$html_welcome = 'Selamat datang di %1$s';
$html_login = 'Masuk log';
$html_user_label = 'Pengguna:';
$html_passwd_label = 'Kata sandi:';
$html_submit = 'Kirim';
$html_help = 'Bantuan';
$html_server_label = 'Server:';
$html_wrong = 'Pengguna atau kata sandi salah';
$html_retry = 'Coba lagi';
$html_remember = 'Ingat pengaturan';
$html_lang_label = 'Bahasa:';
$html_msgperpage_label = 'Pesan perhalaman:';
$html_preferences = 'Preferensi';
$html_full_name_label = 'Nama lengkap:';
$html_email_address_label = 'Alamat surat-e:';
$html_bccself = 'BCC diri';
$html_hide_addresses = 'Sembunyikan alamat';
$html_outlook_quoting = 'Gaya kutipan-Qutlook';
$html_reply_to = 'Balas ke';
$html_use_signature = 'Gunakan tanda tangan';
$html_signature = 'Tanda tangan';
$html_signature_label = 'Tanda tangan:';
$html_reply_leadin_label = 'Balasan diawali:';
$html_prefs_updated = 'Preferensi diperbarui';
$html_manage_folders_link = 'Kelola Folder IMAP';
$html_manage_filters_link = 'Kelola Penyaring Surel';
$html_use_graphical_smilies = 'Gunakan smiley grafis';
$html_sent_folder_label = 'Salin surel terkirim ke folder khusus:';
$html_trash_folder_label = 'Pindahkan surel terhapus ke folder khusus:';
$html_colored_quotes = 'Kutipan berwarna';
$html_display_struct = 'Tampilan teks tersetruktur';
$html_send_html_mail = 'Kirim surel dalam format HTML';
$html_folders = 'Folder';
$html_folders_create_failed = 'Folder tak dapat dibuat!';
$html_folders_sub_failed = 'Tidak bisa berlangganan ke folder!';
$html_folders_unsub_failed = 'Tidak bisa berhenti berlangganan dari folder!';
$html_folders_rename_failed = 'Folder tidak bisa diubah nama!';
$html_folders_updated = 'Folder telah diperbarui';
$html_folder_subscribe = 'Berlangganan ke';
$html_folder_rename = 'Ubah nama';
$html_folder_create = 'Buat foler baru bernama';
$html_folder_remove = 'Berhenti berlangganan dari';
$html_folder_delete = 'Hapus';
$html_folder_to = 'Kepada';
$html_filter_remove = 'Hapus';
$html_filter_body = 'Badan pesan';
$html_filter_subject = 'Subyek pesan';
$html_filter_to = 'Kotak Kepada';
$html_filter_cc = 'Kotak Cc';
$html_filter_from = 'Kotak Dari';
$html_filter_change_tip = 'Untuk mengubah penyaring, tulis/timpa saja kembali.';
$html_reapply_filters = 'Nyalakan kembali semua penyaring';
$html_filter_contains = 'berisi';
$html_filter_name = 'Nama Penyaring';
$html_filter_action = 'Langkah Penyaring';
$html_filter_moveto = 'Pindah ke';
$html_select_one = '--Pilih salahsatu--';
$html_and = 'Dan';
$html_new_msg_in = 'Pesan baru pada';
$html_or = 'atau';
$html_move = 'Pindahkan';
$html_copy = 'Salin';
$html_messages_to = 'Pesan pilihan ke';
$html_gotopage = 'Ke Halaman';
$html_gotofolder = 'Pergi ke Folder';
$html_other_folders = 'Daftar Folder';
$html_page = 'Halaman';
$html_of = 'dari';
$html_view_header = 'Tampilkan kepala';
$html_remove_header = 'Sembunyikan kepala';
$html_inbox = 'Kotak Masuk';
$html_new_msg = 'Tulis';
$html_reply = 'Balas';
$html_reply_short = 'Bl:';
$html_reply_all = 'Balas semua';
$html_forward = 'Teruskan';
$html_forward_short = 'Lnj:';
$html_forward_info = 'Pesan yang diteruskan akan dikirim sebagai lampiran dari pesan ini.';
$html_delete = 'Hapus';
$html_new = 'Baru';
$html_mark = 'Hapus';
$html_att_label = 'Lampiran:';
$html_atts_label = 'Lampiran:';
$html_unknown = '[tidak diketahui]';
$html_part_x = 'Bagian %s';
$html_attach = 'Terlampir';
$html_attach_forget = 'Anda harus melampirkan berkas sebelum mengirim pesan!';
$html_attach_delete = 'Buang Pilihan';
$html_attach_none = 'Anda harus memilih sebuah berkas untuk dilampirkan!';
$html_sort_by = 'Urut berdasarkan';
$html_sort = 'Urutkan';
$html_from = 'Dari';
$html_from_label = 'Dari:';
$html_subject = 'Perihal';
$html_subject_label = 'Perihal:';
$html_date = 'Tanggal';
$html_date_label = 'Tanggal:';
$html_sent_label = 'Kirim:';
$html_wrote = 'tulis';
$html_size = 'Ukuran';
$html_totalsize = 'Jumlah Ukuran';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nama berkas';
$html_to = 'Kepada';
$html_to_label = 'Kepada:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Tidak ada judul';
$html_send = 'Kirim';
$html_cancel = 'Batalkan';
$html_no_mail = 'Tidak ada pesan.';
$html_logout = 'Keluar log';
$html_msg = 'Pesan';
$html_msgs = 'Pesan';
$html_configuration = 'Server ini belum didirikan!';
$html_priority = 'Prioritas';
$html_priority_label = 'Prioritas:';
$html_lowest = 'Terendah';
$html_low = 'Rendah';
$html_normal = 'Normal';
$html_high = 'Tinggi';
$html_highest = 'Tertinggi';
$html_flagged = 'Ditandai';
$html_spam = 'Spam';
$html_spam_warning = 'Pesan ini telah dikelompokkan sabagai spam.';
$html_receipt = 'Minta tanda kembalian';
$html_select = 'Pilih';
$html_select_all = 'Kembalikan Pilihan';
$html_select_contacts = 'Pilih kontak';
$html_loading_image = 'Memuat gambar';
$html_send_confirmed = 'Surel Anda diterima untuk dikirim';
$html_no_sendaction = 'Tidak ada langkah yang dilakukan. Coba nyalakan JavaScript.';
$html_error_occurred = 'Kesalahan terjadi';
$html_prefs_file_error = 'Tidak bisa membuka berkas preferensi untuk menulis.';
$html_wrap = 'Jumlah karakter untuk membungkus pesan:';
$html_wrap_none = 'Tanpa bungkus';
$html_usenet_separator = 'Pemisah Usenet ("-- \n") sebelum tanda tangan';
$html_mark_as = 'Tandai sebagai';
$html_read = 'sudah dibaca';
$html_unread = 'belum dibaca';
$html_encoding_label = 'Pengkodean karakter:';
$html_add = 'Tambahkan';
$html_contacts = '%1$s kontak';
$html_modify = 'Ubah';
$html_back = 'Kembali';
$html_contact_add = 'Tambah kontak baru';
$html_contact_mod = 'Ubah kontak';
$html_contact_first = 'Nama awal';
$html_contact_last = 'Nama akhir';
$html_contact_nick = 'Panggilan';
$html_contact_mail = 'Surel';
$html_contact_list = 'Daftar kontak %1$s';
$html_contact_del = 'dari daftar kontak';
$html_contact_count = '%1$d kontak';
$html_contact_err1 = 'Jumlah maksimum kontak adalah "%$d"';
$html_contact_err2 = 'Anda tak dapat menambahkan kontak baru';
$html_contact_err3 = 'Anda tak punya hak masuk ke daftar kontak';
$html_contact_none = 'Tak ada kontak yang ditemukan.';
$html_del_msg = 'Hapus pesan terpilih?';
$html_down_mail = 'Unduh';
$original_msg = '-- Pesan Asli --';
$to_empty = 'Kotak \'Kepada\' jangan dikosongkan!';
$html_images_warning = 'Demi keamanan Anda, gambar tertentu tidak ditampilkan.';
$html_images_display = 'Tampilkan gambar';
$html_smtp_error_no_conn = 'Tidak bisa membuka koneksi SMTP';
$html_smtp_error_unexpected = 'Respon SMTP tak terduga:';
$lang_could_not_connect = 'Tak dapat menghubungi server';
$lang_invalid_msg_num = 'Nomor pesan buruk';
$html_file_upload_attack = 'Kemungkinan serangan unggah berkas';
$html_invalid_email_address = 'Alamat surel salah';
$html_invalid_msg_per_page = 'Jumlah pesan per halaman salah';
$html_invalid_wrap_msg = 'Lebar bungkus pesan salah';
$html_seperate_msg_win = 'Pesan di jendela lain';
$html_err_file_contacts = 'Tidak bisa membuka berkas kontak untuk menulis.';
$html_session_file_error = 'Tidak bisa membuka berkas sesi untuk menulis.';
$html_login_not_allowed = 'Masuk log belum diperbolehkan karena masalah koneksi.';
$lang_err_send_delay = 'Anda harus menunggu antara dua surel (%1$d detik)';
$html_search = 'Cari';
